Changes
~~~~~~~
1.2 (2013-11-07)
----------------
 
- added a new ``assertNoRecord(model, domain)`` utility 
 
1.1 (2012-08-05)
----------------

- added utility and assertion methods
- corrected documentation 

1.0 (2012-07-13)
----------------

- initial release

